Package: EDASeq
Version: 2.40.0
Title: Exploratory Data Analysis and Normalization for RNA-Seq
Description: Numerical and graphical summaries of RNA-Seq read data.
        Within-lane normalization procedures to adjust for GC-content
        effect (or other gene-level effects) on read counts: loess
        robust local regression, global-scaling, and full-quantile
        normalization (Risso et al., 2011). Between-lane normalization
        procedures to adjust for distributional differences between
        lanes (e.g., sequencing depth): global-scaling and
        full-quantile normalization (Bullard et al., 2010).
Authors@R: c(person("Davide", "Risso", email = "risso.davide@gmail.com",
	          role = c("aut", "cre", "cph")),
	     person("Sandrine", "Dudoit", role = "aut"),
	     person("Ludwig", "Geistlinger", role = "ctb"))
Author: Davide Risso [aut, cre, cph], Sandrine Dudoit [aut], Ludwig Geistlinger [ctb]
Maintainer: Davide Risso <risso.davide@gmail.com>
Date: 08-30-2011
Depends: Biobase (>= 2.15.1), ShortRead (>= 1.11.42)
Imports: methods, graphics, BiocGenerics, IRanges (>= 1.13.9),
        aroma.light, Rsamtools (>= 1.5.75), biomaRt, Biostrings,
        AnnotationDbi, GenomicFeatures, GenomicRanges, BiocManager
Suggests: BiocStyle, knitr, yeastRNASeq, leeBamViews, edgeR,
        KernSmooth, testthat, DESeq2, rmarkdown
VignetteBuilder: knitr
License: Artistic-2.0
LazyLoad: yes
biocViews: ImmunoOncology, Sequencing, RNASeq, Preprocessing,
        QualityControl, DifferentialExpression
URL: https://github.com/drisso/EDASeq
BugReports: https://github.com/drisso/EDASeq/issues
RoxygenNote: 7.1.0
git_url: https://git.bioconductor.org/packages/EDASeq
git_branch: RELEASE_3_20
git_last_commit: fdb405f
git_last_commit_date: 2024-10-29
Repository: Bioconductor 3.20
Date/Publication: 2024-10-29
NeedsCompilation: no
Packaged: 2024-10-30 00:31:56 UTC; biocbuild
